"""
Fast Computation of Latent Correlations for Mixed Data
======================================================

"""
import os
import sys
sys.path.insert(0, os.path.abspath('.'))

from latentcor.latentcor import gen_data, get_tps, latentcor

__author__ = 'Mingze Huang, Christian L. Müller, Irina Gaynanova'
__email__ = 'mingzehuang@gmail.com, christian.mueller@stat.uni-muenchen.de, irinag@stat.tamu.edu'
__version__ = '0.2.3'

